==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/STANDARDWOCHILDID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour STANDARDWOCHILDID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="STANDARDWOCHILDID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARENTSTANDARDWO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CHILDSTANDARDWO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STEP"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STANDARDWOCHILDID_Type", propOrder = {
    "parentstandardwo",
    "childstandardwo",
    "sequence",
    "step"
})
public class STANDARDWOCHILDID_Type {

    @XmlElement(name = "PARENTSTANDARDWO", required = true)
    protected STDWOID_Type parentstandardwo;
    @XmlElement(name = "CHILDSTANDARDWO", required = true)
    protected STDWOID_Type childstandardwo;
    @XmlElement(name = "SEQUENCE")
    protected long sequence;
    @XmlElement(name = "STEP")
    protected long step;

    /**
     * Obtient la valeur de la propriété parentstandardwo.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getPARENTSTANDARDWO() {
        return parentstandardwo;
    }

    /**
     * Définit la valeur de la propriété parentstandardwo.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setPARENTSTANDARDWO(STDWOID_Type value) {
        this.parentstandardwo = value;
    }

    /**
     * Obtient la valeur de la propriété childstandardwo.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getCHILDSTANDARDWO() {
        return childstandardwo;
    }

    /**
     * Définit la valeur de la propriété childstandardwo.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setCHILDSTANDARDWO(STDWOID_Type value) {
        this.childstandardwo = value;
    }

    /**
     * Obtient la valeur de la propriété sequence.
     * 
     */
    public long getSEQUENCE() {
        return sequence;
    }

    /**
     * Définit la valeur de la propriété sequence.
     * 
     */
    public void setSEQUENCE(long value) {
        this.sequence = value;
    }

    /**
     * Obtient la valeur de la propriété step.
     * 
     */
    public long getSTEP() {
        return step;
    }

    /**
     * Définit la valeur de la propriété step.
     * 
     */
    public void setSTEP(long value) {
        this.step = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/STANDARDWOCHILDID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for STANDARDWOCHILDID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="STANDARDWOCHILDID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARENTSTANDARDWO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CHILDSTANDARDWO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STEP"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STANDARDWOCHILDID_Type", propOrder = {
    "parentstandardwo",
    "childstandardwo",
    "sequence",
    "step"
})
public class STANDARDWOCHILDID_Type {

    @XmlElement(name = "PARENTSTANDARDWO", required = true)
    protected STDWOID_Type parentstandardwo;
    @XmlElement(name = "CHILDSTANDARDWO", required = true)
    protected STDWOID_Type childstandardwo;
    @XmlElement(name = "SEQUENCE")
    protected long sequence;
    @XmlElement(name = "STEP")
    protected long step;

    /**
     * Gets the value of the parentstandardwo property.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getPARENTSTANDARDWO() {
        return parentstandardwo;
    }

    /**
     * Sets the value of the parentstandardwo property.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setPARENTSTANDARDWO(STDWOID_Type value) {
        this.parentstandardwo = value;
    }

    /**
     * Gets the value of the childstandardwo property.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getCHILDSTANDARDWO() {
        return childstandardwo;
    }

    /**
     * Sets the value of the childstandardwo property.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setCHILDSTANDARDWO(STDWOID_Type value) {
        this.childstandardwo = value;
    }

    /**
     * Gets the value of the sequence property.
     * 
     */
    public long getSEQUENCE() {
        return sequence;
    }

    /**
     * Sets the value of the sequence property.
     * 
     */
    public void setSEQUENCE(long value) {
        this.sequence = value;
    }

    /**
     * Gets the value of the step property.
     * 
     */
    public long getSTEP() {
        return step;
    }

    /**
     * Sets the value of the step property.
     * 
     */
    public void setSTEP(long value) {
        this.step = value;
    }

}
